@@ -111,7 +111,7 @@ class InterpretJAAQL:
 
     def transform(self, operation: Union[dict, str], conn=None, skip_commit: bool = False, wait_hook: queue.Queue = None,
                   encryption_key: bytes = None, autocommit: bool = False, canned_query_service=None, prevent_unused_parameters: bool = True,
-                  do_prepare_only: str = False):
+                  do_prepare_only: str = False, and_return_connection_mid_transaction: bool = False):
         if (not isinstance(operation, dict)) and (not isinstance(operation, str)):
             raise HttpStatusException(ERR_malformed_operation_type, HTTPStatus.BAD_REQUEST)
 
@@ -253,7 +253,7 @@ class InterpretJAAQL:
                     exc_row_idx = cur_row_idx
                     exc_parameters = cur_parameters
                     exc_row_number = cur_parameters.get(KEY__row_number)
-                    last_query, found_parameter_dictionary = self.pre_prepare_statement(cur_query, cur_parameters, for_prepare=do_prepare_only is not None)
+                    last_query, found_parameter_dictionary = self.pre_prepare_statement(cur_query, cur_parameters, for_prepare=do_prepare_only is True)
 
                     enc_parameter_dictionary = {}
 
@@ -263,7 +263,7 @@ class InterpretJAAQL:
                         last_query, enc_parameter_dictionary = self.pre_prepare_statement(last_query, encrypt_parameters,
                                                                                           match_regex=REGEX_enc_query_argument,
                                                                                           encryption_key=encryption_key,
-                                                                                          for_prepare=do_prepare_only is not None)
+                                                                                          for_prepare=do_prepare_only is True)
 
                     last_query = self.encrypt_literals(last_query, encryption_key)
                     found_params = {**found_parameter_dictionary, **enc_parameter_dictionary}
@@ -342,10 +342,16 @@ class InterpretJAAQL:
 
             err = ex
 
+        #
+        # and_return_connection_mid_transaction
+        # err
+
         if was_conn_none:
-            self.db_interface.put_conn_handle_error(conn, err, STATEMENT_empty, skip_rollback_commit=skip_commit)
-        else:
-            self.db_interface.handle_error(conn, err, STATEMENT_empty)
+            self.db_interface.put_conn_handle_error(conn, err, skip_rollback_commit=skip_commit)
+        elif not and_return_connection_mid_transaction:
+            self.db_interface.handle_error(conn, err)
+        elif err is not None:
+            raise err
 
         return ret
 
